Index: src/ia32/code-stubs-ia32.h |
diff --git a/src/ia32/code-stubs-ia32.h b/src/ia32/code-stubs-ia32.h |
index acf4a6f94879968fc4629389f7f2d756383e844d..82d812f08b642108f38370a7b5a1a182304e2ebf 100644 |
--- a/src/ia32/code-stubs-ia32.h |
+++ b/src/ia32/code-stubs-ia32.h |
@@ -234,16 +234,20 @@ class StringHelper : public AllStatic { |
Register scratch, // Neither of above. |
bool ascii); |
// Probe the symbol table for a two character string. If the string is |
// not found by probing a jump to the label not_found is performed. This jump |
// does not guarantee that the string is not in the symbol table. If the |
// string is found the code falls through with the string in register eax. |
Søren Thygesen Gjesse
2010/09/01 11:19:31
Maybe extend the comment to say that c1 and c2 are
Vitaly Repeshko
2010/09/01 17:21:51
Done.
|
+ // the symbol table. If the string is found the code falls through |
+ // with the string in register eax. |
static void GenerateTwoCharacterSymbolTableProbe(MacroAssembler* masm, |
Register c1, |
Register c2, |
Register scratch1, |
Register scratch2, |
Register scratch3, |
+ Label* not_probed, |
Søren Thygesen Gjesse
2010/09/01 11:19:31
How about renaming not_probed to not_found_c1_c2_p
@@ -234,16 +234,20 @@ class StringHelper : public AllStatic { |
Register scratch, // Neither of above. |
bool ascii); |
- // Probe the symbol table for a two character string. If the string is |
- // not found by probing a jump to the label not_found is performed. This jump |
- // does not guarantee that the string is not in the symbol table. If the |
- // string is found the code falls through with the string in register eax. |
+ // Probe the symbol table for a two character string. If the string |
+ // requires non-standard hashing a jump to the label not_probed is |
+ // performed and registers c1 and c2 are preserved. If the string is |
+ // not found by probing a jump to the label not_found is |
+ // performed. This jump does not guarantee that the string is not in |
Søren Thygesen Gjesse
2010/09/01 11:19:31
Vitaly Repeshko
2010/09/01 17:21:51
I think having this described in the comment is en
|
Label* not_found); |
// Generate string hash. |